pub enum ErrorKind {
Fatal,
Unreachable,
Other,
}Expand description
Classification of an IPC error, returned by IpcErrorKind::kind.
Variants
Fatal
The client can no longer make progress, so the shared processing loop should stop.
Unreachable
The destination could not be reached (e.g. the peer transport is not connected); The client should continue to process messages. A peer may become reachable later.
Other
Any other, recoverable failure: only the current operation failed, so the client should stay running and continue processing other messages.